@@ -4,12 +4,14 @@ import csv
 import boto3
 import requests
 import hashlib
+from itertools import chain
+from types import GeneratorType
 from datetime import datetime, timedelta
 from io import StringIO, BytesIO
 from boto3.s3.transfer import TransferConfig
 from Crypto.Cipher import AES
 from base64 import b64encode, b64decode
-from typing import Union, Optional, List, Iterator, Generator
+from typing import Union, Optional, List, Iterator, Generator, Any, Tuple
 
 from django.conf import settings
 
@@ -429,3 +431,12 @@ def dates_chunker(
             (date_from + timedelta(days=default_delta - 1)),
         ]
         date_from = date_from + timedelta(days=default_delta)
+
+
+def has_items(iterable: Any) -> Tuple[bool, Any]:
+    if isinstance(iterable, GeneratorType):
+        try:
+            return True, chain([next(iterable)], iterable)
+        except StopIteration:
+            return False, []
+    return bool(iterable), iterable
